# This file is part of the sos project: https://github.com/sosreport/sos
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# version 2 of the GNU General Public License.
#
# See the LICENSE file in the source distribution for further information.

import platform
from sos.report.plugins import Plugin, PluginOpt, RedHatPlugin, DebianPlugin, \
    UbuntuPlugin, CosPlugin
from sos.report.plugins import IndependentPlugin

class KDump(Plugin, IndependentPlugin):

    short_desc = 'Kdump crash dumps'

    plugin_name = "kdump"
    verify_packages = ('kexec-tools',)
    profiles = ('system', 'debug', 'kernel')

    def setup(self):
        self.add_copy_spec([
            "/proc/cmdline",
            "/etc/sysconfig/kdump",
            "/proc/sys/kernel/panic",
            "/proc/sys/kernel/panic_on_oops",
            "/sys/kernel/kexec_loaded",
            "/sys/kernel/fadump_enabled",
            "/sys/kernel/fadump/enabled",
            "/sys/kernel/fadump_registered",
            "/sys/kernel/fadump/registered",
            "/sys/kernel/fadump/mem_reserved",
            "/sys/kernel/kexec_crash_size"
        ])
        self.add_copy_spec("/var/crash/**")

        self.add_copy_spec("/sys/kernel/kexec_crash_loaded",
                           tags="kexec_crash_loaded")

        self.add_cmd_output(["systemctl status kdump"], suggest_filename="kdump_test")
        self.add_cmd_output(["cat /sys/kernel/kexec_crash_loaded", "cat /proc/cmdline"])
        self.add_cmd_output("ls -alhR /var/crash/")
        
# vim: set et ts=4 sw=4 :
