# This file is part of the sos project: https://github.com/sosreport/sos
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# version 2 of the GNU General Public License.
#
# See the LICENSE file in the source distribution for further information.

import platform
from sos.report.plugins import Plugin, PluginOpt, RedHatPlugin, DebianPlugin, \
    UbuntuPlugin, CosPlugin
from sos.report.plugins import IndependentPlugin
import subprocess

def execute_shell(cmd):
    try:
        ret = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        out, err = ret.communicate()
        if len(out) != 0:
            out = out.decode("utf-8")
        if len(out) == 0:
            return (" ", 1)

        return (out, err)
    except Exception as e:
        print(e)
        return (" ", -1)


def test_kdump():
    kexec_crash_loaded = False
    kdump_service_active = False

    cmd = "cat /sys/kernel/kexec_crash_loaded"
    ret = execute_shell(cmd)
    if int(ret[0]) == 1:
        kexec_crash_loaded = True

    cmd = "systemctl status kdump.service  | grep Active"
    ret = execute_shell(cmd)
    if ret[0].find("Active: active") != -1:
        kdump_service_active = True

    if kexec_crash_loaded == True and kdump_service_active == True:
        return True

    return False


def test_stap():
    cmd = ''' stap -ve 'probe kernel.function("schedule"){printf("success#@") exit()}' '''
    ret = execute_shell(cmd)
    if ret[0].find("success#@") != -1:
        return True
    return False


class Mixed(Plugin, IndependentPlugin):

    short_desc = 'Mixed'

    plugin_name = "mixed"
    profiles = ('system', 'debug', 'kernel')

    def setup(self):
        cmd = "echo 0 "
        if test_kdump() == True:
            cmd = "echo 1"
        self.add_cmd_output(cmd, suggest_filename="kdump")
        cmd = "echo 0"
        if test_stap():
            cmd = "echo 1"
        self.add_cmd_output(cmd, suggest_filename="systemtap")

# vim: set et ts=4 sw=4 :
